import { mdiPound, mdiContentCopy, mdiContentPaste } from '@mdi/js'
import Icon from '@mdi/react'
import { HexColorInput, HexColorPicker } from 'react-colorful'

import { toast } from '@redwoodjs/web/toast'

interface ColorPickerProps {
  color: string
  setColor: React.Dispatch<React.SetStateAction<string>>
}

const ColorPicker = ({ color, setColor }: ColorPickerProps) => {
  return (
    <div className="flex flex-col space-y-2 bg-base-100 p-2 rounded-xl w-min">
      <section className="w-52">
        <HexColorPicker color={color} onChange={setColor} />
      </section>
      <div className="flex space-x-2 w-52">
        {/* eslint-disable-next-line jsx-a11y/label-has-associated-control */}
        <label className="input input-bordered flex items-center gap-2 input-sm w-full grow">
          <Icon path={mdiPound} className="size-4 opacity-70" />
          <HexColorInput color={color} className="w-16" />
        </label>
        <button
          type="button"
          className="btn btn-square btn-sm"
          onClick={async () => {
            try {
              await navigator.clipboard.writeText(color)
              toast.success('Copied color to clipboard')
            } catch {
              toast.error(`Failed to copy, please try again`)
            }
          }}
        >
          <Icon path={mdiContentCopy} className="size-4" />
        </button>
        <button
          type="button"
          className="btn btn-square btn-sm  "
          onClick={async () => {
            try {
              setColor(await navigator.clipboard.readText())
            } catch {
              toast.error(`Failed to paste, please try again`)
            }
          }}
        >
          <Icon path={mdiContentPaste} className="size-4" />
        </button>
      </div>
    </div>
  )
}

export default ColorPicker
