import type { FindProjectById, FindProjectByIdVariables } from 'types/graphql'

import type {
  CellSuccessProps,
  CellFailureProps,
  TypedDocumentNode,
} from '@redwoodjs/web'

import CellEmpty from 'src/components/Cell/CellEmpty/CellEmpty'
import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'
import Project from 'src/components/Project/Project/Project'

export const QUERY: TypedDocumentNode<
  FindProjectById,
  FindProjectByIdVariables
> = gql`
  query FindProjectById($id: Int!) {
    project: project(id: $id) {
      id
      title
      description
      date
      links
      images
      tags {
        id
        tag
        color
      }
    }
  }
`

export const Loading = () => <CellLoading />
export const Empty = () => <CellEmpty />
export const Failure = ({
  error,
}: CellFailureProps<FindProjectByIdVariables>) => <CellFailure error={error} />
export const Success = ({
  project,
}: CellSuccessProps<FindProjectById, FindProjectByIdVariables>) => (
  <Project project={project} />
)
